==> phpwebthings-0.6.0.zip: phpwebthings-0.6.0/modules/news/lang/msg_ptbr.php <==
<?php
// lang file for news
// News
$lang["NEWS_TITLE"]="Novidades";
$lang["NEWS_POSTED_BY"]="por ";
$lang["NEWS_SAME_CAT"]="outras ";
$lang["NEWS_CLICK_MORE"]="mais...";
$lang["NEWS_SUBMIT_TITLE"]="Enviar novidade";
$lang["NEWS_EDIT_TITLE"] = "Alterando novidade";
$lang["NEWS_PENDING_TITLE"] = "Novidades pendentes";
$lang["NEWS_DELETE_TITLE"] = "Excluir";
$lang["NEWS_SUBMIT_DONE"]="Novidade publicada";
$lang["NEWS_SUBMIT_THANKS"]="Sua notcia foi publicada!<br><br>Obrigado!";
$lang["NEWS_SUBMIT_THANKS_MAIL_TITLE"]="Uma novidade foi publicada em seu site";
$lang["NEWS_SUBMIT_THANKS_MAIL"]="Uma novidade Foi publicada em seu site e j est ativa";
$lang["NEWS_SUBMIT_THANKS2"]="Sua notcia foi enviada ao administrador.<br><br>Obrigado!";
$lang["NEWS_SUBMIT_THANKS2_MAIL"]="Uma novidade aguarda sua ativao em seu site.";
$lang["NEWS_FIELD_TITLE"]="Ttulo:";
$lang["NEWS_FIELD_IMAGE"]="Imagem:";
$lang["NEWS_FIELD_CAT"]="Categoria:";
$lang["NEWS_FIELD_TEXT"]="Chamada:";
$lang["NEWS_FIELD_FULL_TEXT"]="Texto (opcional):";
$lang["NEWS_FIELD_ACTIVE"]="Publicada";
$lang["NEWS_FIELD_ARCHIVED"]="Arquivada";
$lang["NEWS_FIELD_UID"]="Usurio:";
$lang["NEWS_FIELD_DATE"]="Data:";
$lang["NEWS_FIELD_ALIGN"]="Alinhamento da imagem:";
$lang["NEWS_PENDING"]="Ativao pendente para estas notcias";
$lang["NEWS_PENDING_NONE"]="No existem notcias pendentes para ativar";
$lang["NEWS_PENDING_MSG"] = "Existem novidades aguardando ativao.";
$lang["NEWS_EDIT"]="editar";
$lang["NEWS_ARCHIVED"]="Ver as notcias arquivadas";
$lang["NEWS_DELETED"] = "Notcia excluda";
$lang["NOT_LOGGED_NEWS"]="Desculpe, mas voc precisa logar para enviar uma notcia. Se voc ainda no tem um login, por que no se registra?  de graa!";
?>

==> phpwebthings-1.0.zip: phpwebthings-1.0/modules/news/lang/msg_ptbr.php <==
<?php
// lang file for news
// News
$lang["NEWS_TITLE"]="Novidades";
$lang["NEWS_POSTED_BY"]="por ";
$lang["NEWS_SAME_CAT"]="outras ";
$lang["NEWS_CLICK_MORE"]="mais...";
$lang["NEWS_SUBMIT_TITLE"]="Enviar novidade";
$lang["NEWS_EDIT_TITLE"] = "Alterando novidade";
$lang["NEWS_PENDING_TITLE"] = "Novidades pendentes";
$lang["NEWS_DELETE_TITLE"] = "Excluir";
$lang["NEWS_SUBMIT_DONE"]="Novidade publicada";
$lang["NEWS_SUBMIT_THANKS"]="Sua notcia foi publicada!<br><br>Obrigado!";
$lang["NEWS_SUBMIT_THANKS_MAIL_TITLE"]="Uma novidade foi publicada em seu site";
$lang["NEWS_SUBMIT_THANKS_MAIL"]="Uma novidade Foi publicada em seu site e j est ativa";
$lang["NEWS_SUBMIT_THANKS2"]="Sua notcia foi enviada ao administrador.<br><br>Obrigado!";
$lang["NEWS_SUBMIT_THANKS2_MAIL"]="Uma novidade aguarda sua ativao em seu site.";
$lang["NEWS_FIELD_TITLE"]="Ttulo:";
$lang["NEWS_FIELD_IMAGE"]="Imagem:";
$lang["NEWS_FIELD_CAT"]="Categoria:";
$lang["NEWS_FIELD_TEXT"]="Chamada:";
$lang["NEWS_FIELD_FULL_TEXT"]="Texto (opcional):";
$lang["NEWS_FIELD_ACTIVE"]="Publicada";
$lang["NEWS_FIELD_ARCHIVED"]="Arquivada";
$lang["NEWS_FIELD_UID"]="Usurio:";
$lang["NEWS_FIELD_DATE"]="Data:";
$lang["NEWS_FIELD_ALIGN"]="Alinhamento da imagem:";
$lang["NEWS_PENDING"]="Ativao pendente para estas notcias";
$lang["NEWS_PENDING_NONE"]="No existem notcias pendentes para ativar";
$lang["NEWS_PENDING_MSG"] = "Existem novidades aguardando ativao.";
$lang["NEWS_EDIT"]="editar";
$lang["NEWS_ARCHIVED"]="Ver as notcias arquivadas";
$lang["NEWS_DELETED"] = "Notcia excluda";
$lang["NOT_LOGGED_NEWS"]="Desculpe, mas voc precisa logar para enviar uma notcia. Se voc ainda no tem um login, por que no se registra?  de graa!";
$lang["NEWS_CAT_EDIT"] = "Cat. Notcias";
$lang["NEWS_ARCH_TITLE"] = "Arquivar Notcias";
$lang["NEWS_SEARCH"] = "Busca";
$lang["NEWS_INVALID_SEARCH"] = "Busca invlida.";
$lang["NEWS_SEARCH_DATE"] = "Data";
$lang["NEWS_SEARCH_TITLE"] = "Ttulo";
?>
